@@ -15,8 +15,8 @@
 # MA  02111-1307  USA
 
 # Copyrights (C)
-# for this R-port: 
-#   1999 - 2005, Diethelm Wuertz, GPL
+# for this R-port:
+#   1999 - 2008, Diethelm Wuertz, Rmetrics Foundation, GPL
 #   Diethelm Wuertz <wuertz@itp.phys.ethz.ch>
 #   info@rmetrics.org
 #   www.rmetrics.org
@@ -29,28 +29,6 @@
 
 ################################################################################
 
-
-.First.lib =  
-function(lib, pkg)
-{   
-    # Startup Mesage and Desription:
-    MSG <- if(getRversion() >= "2.5") packageStartupMessage else message
-    dsc <- packageDescription(pkg)
-    if(interactive() || getOption("verbose")) { 
-        # not in test scripts
-        MSG(sprintf("\nPackage %s (%s) loaded.\n%s\n",
-            pkg, dsc$Version, dsc$Title),
-            "Rmetrics, (C) 1999-2007, Diethelm Wuertz, GPL\n")
-    }
-
-    # Load dll:
-    library.dynam("fGarch", pkg, lib) 
-}
-
-
-if(!exists("Sys.setenv", mode = "function")) # pre R-2.5.0, use "old form"
-    Sys.setenv <- Sys.putenv
-
+## .First.lib <- function(lib, pkg) library.dynam("fGarch", pkg, lib)
 
 ################################################################################
-
